.. currentmodule:: kombu.transport

.. automodule:: kombu.transport

    .. contents::
        :local:

    Data
    ----

    .. data:: DEFAULT_TRANSPORT

        Default transport used when no transport specified.

    .. data:: TRANSPORT_ALIASES

        Mapping of transport aliases/class names.

    Functions
    ---------

    .. autofunction:: get_transport_cls
    .. autofunction:: resolve_transport
